#
# spec file for package python-iso8601
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-iso8601
Version:        2.1.0
Release:        1.3
Summary:        Python module to parse ISO 8601 dates
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/micktwomey/pyiso8601
Source:         https://files.pythonhosted.org/packages/source/i/iso8601/iso8601-%{version}.tar.gz
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core}
BuildRequires:  %{python_module pytest >= 2.4.2}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
This module parses the most common forms of ISO 8601 date strings (e.g.
2007-01-14T20:34:22+00:00) into datetime objects.

%prep
%setup -q -n iso8601-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst
%{python_sitelib}/iso8601
%{python_sitelib}/iso8601-%{version}.dist-info

%changelog
* Sun Mar 24 2024 Dirk Müller <dmueller@suse.com>
- update to 2.1.0:
  * Use ruff for linting
- update to 2.0.0:
  * Add Python 3.12 support
  * Fix test_fixedoffset_eq by adding an actual assertion
  * Drop Python 3.6 support (3.6 is end of life)
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 1.1.0:
  * raise ParseError if we get an exception on is_iso8601()
  * Add is_iso8601() function
  * Update license years
* Sun Dec 12 2021 Ben Greiner <code@bnavigator.de>
- Explicitly require test depenendency pytz (it's only optional in
  hypothesis[pytz])
* Mon Dec  6 2021 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Add missing `__all__` in `__init__.py`
  * Add missing py.typed file (as per PEP 561), keeps mypy happy :D
  * Drop python < 3.6 support
  * Add type annotations to code
  * Remove external type annotations in pyi
  * Switch to poetry for packaging
  * Simplify internals and remove old compatability code
  * Switch to nox for testing
  * Lots of small project development changes
* Sun Aug  1 2021 Dirk Müller <dmueller@suse.com>
- update to 0.1.16:
  * Include `docs/` into sdist tarball
  * Include .pyi files in built wheels and source tarballs
* Thu Feb 18 2021 Dirk Müller <dmueller@suse.com>
- update to 0.1.14:
  * Add GitHub build actions for project
  * Add project URLs in setup.py (thanks to Steve Piercy)
  * Update README links (thanks to Steve Piercy)
  * Fix handling of README in setup.py (encoding fun in 3.5, 3.6 and pypy3)
  * Fix README links (thanks to Chris Barker)
  * Add Python 3.9 to test matrix (thanks to Luciano Mammino)
  * Add type hints (thanks to Brett Cannon)
  * Derive `ParseError` from `ValueError` (thanks to Lex Robinson)
* Mon Sep 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.1.13:
  * Move to GitHub (https://github.com/micktwomey/pyiso8601).
  * Remove python 2.6, 3.2, 3.3 and 3.4 from tests
  * Add python 3.7 and 3.8 to tests
* Fri Dec 20 2019 Dirk Mueller <dmueller@suse.com>
- update to 0.1.12:
  * Fix class reference for iso8601.Utc in module docstring
* Fri Mar 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Downgrade to 0.1.11:
  * Reverts back to avoid API change that caused iso8601.Utc not
    working on py3 (Fedora and Deb both ship this version)
* Fri Mar 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Download the sources from pypi and run fdupes
* Tue Jan  8 2019 Jan Engelhardt <jengelh@inai.de>
- Update descriptions.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Nov 10 2017 arun@gmx.de
- update to version 0.1.12:
  * Fix class reference for iso8601.Utc in module docstring (thanks to
    felixschwarz in
    https://bitbucket.org/micktwomey/pyiso8601/pull-requests/7/fix-class-reference-for-iso8601utc-in/diff)
* Thu Mar 16 2017 tbechtold@suse.com
- Switch to singlespec approach
* Mon Mar 14 2016 tbechtold@suse.com
- update to 0.1.11:
  * Remove logging
  * Add support for , as separator for fractional part
  * Add Python 3.4 and 3.5 to tox test config.
  * Add PyPy 3 to tox test config.
  * Link to documentation at http://pyiso8601.readthedocs.org/
* Wed Mar 12 2014 speilicke@suse.com
- Update to version 0.1.10
  + Fixes https://bitbucket.org/micktwomey/pyiso8601/issue/14/regression-yyyy-mm-no-longer-parses
  + Adds YYYY as a valid date (uses 1 for both month and day)
  + Woo, semantic versioning, .10 at last.
- Changes from version 0.1.9:
  + Lots of fixes tightening up parsing from jdanjou.
  + Release addresses https://bitbucket.org/micktwomey/pyiso8601/issue/13/new-release-based-on-critical-bug-fix
- Run tests again
* Thu Feb 13 2014 rschweikert@suse.com
- Include in SLE 12 (FATE #316168)
* Fri Oct 25 2013 dmueller@suse.com
- update to 0.1.8:
  * Remove +/- chars from README.rst and ensure tox tests run using LC_ALL=C.
  * Fix parsing of microseconds
  * Correct negative timezone offsets
  * Wow, it's alive! First update since 2007
  * Moved over to https://bitbucket.org/micktwomey/pyiso8601
  * Add support for python 3
  * Switched to py.test and tox for testing
  * Make seconds optional in date format
  * Correctly raise ParseError for more invalid inputs
  * Support more variations of ISO 8601 dates, times and time zone specs.
  * Fix microsecond rounding issues
  * Fix pickling and deepcopy of returned datetime objects
  * Fix timezone offsets without a separator
  * "Z" produces default timezone if one is specified
  * Handle compact date format
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Jan  7 2012 alexandre@exatati.com.br
- Regenerate spec file with py2pack;
- Now build as noarch;
- Bzip2 source file.
* Mon May 31 2010 toms@suse.de
- Fixed Group: Development/Libraries/Python to make it consistent
  with other Python packages
- Added copyright notice
- Added .changes file
